@@ -5,7 +5,7 @@
 
 namespace SWF {
 
-class Shape;
+class GlyphShape;
 	
 class GlyphList : public Item {
 	/* glyph lists have strange offsetting stuff, so we do them manually */
@@ -14,18 +14,18 @@ class GlyphList : public Item {
 		~GlyphList();
 		virtual bool parse( Reader *r, int end, Context *ctx );
 		virtual void dump( int indent, Context *ctx );
-		virtual size_t getSize( Context *ctx );
+		virtual size_t calcSize( Context *ctx, int start_at );
 		virtual void write( Writer *w, Context *ctx );
 		virtual void writeXML( xmlNodePtr node, Context *ctx );
 		virtual void parseXML( xmlNodePtr node, Context *ctx );
 	
 		void allocate( int n );
-		Shape *getShapeN( int n );
+		GlyphShape *getShapeN( int n );
 		void setMapN( int n, int m );
 	
 	protected:
 		int nGlyphs;
-		Shape *glyphs;
+		GlyphShape *glyphs;
 		int *map;
 };
 
