@@ -16,9 +16,12 @@ ShapeMaker::ShapeMaker( List<ShapeItem>* e, double fx, double fy, double ofsx, d
 	offsety = ofsy;
 	lastx = lasty = 0;
 	diffx = diffy = 0;
+	have_first = false;
+	
+	fillStyle0 = lineStyle = fillStyle1 = -1;
 }
 
-void ShapeMaker::setupR( double _x,double _y, int fillStyle0, int fillStyle1, int lineStyle ) {
+void ShapeMaker::setupR( double _x, double _y ) {
 	roundReset();
 	int x = roundX(factorx * ( _x ) );
 	int y = roundY(factory * ( _y ) );
@@ -49,6 +52,8 @@ void ShapeMaker::setupR( double _x,double _y, int fillStyle0, int fillStyle1, in
 			
 	edges->append( setup );
 
+	minmax( x+(lastx*factorx), y+(lasty*factory) );
+	
 //	fprintf(stderr,"setup %i/%i\n", x, y );
 }
 
@@ -64,6 +69,7 @@ void ShapeMaker::lineToR( double _x, double _y ) {
 	segment->setx( x );
 	segment->sety( y );
 	edges->append( segment );
+	minmax( x+(lastx*factorx), y+(lasty*factory) );
 }
 
 void ShapeMaker::curveToR( double _cx, double _cy, double ax, double ay ) {
@@ -83,6 +89,7 @@ void ShapeMaker::curveToR( double _cx, double _cy, double ax, double ay ) {
 	segment->setx2( x );
 	segment->sety2( y );
 	edges->append( segment );
+	minmax( x+(lastx*factorx), y+(lasty*factory) );
 }
 
 // cubic to quadratic bezier functions
@@ -93,7 +100,7 @@ Point intersectLines( Point p1, Point p2, Point p3, Point p4 ) {
 	double x4 = p4.x, y4 = p4.y;
 	double dx1 = p2.x-x1;
 	double dx2 = p3.x-x4;
-	if( dx1 == 0 && dx2 == 0 ) return Point();
+	if( dx1 == 0 && dx2 == 0 ) return Point(p1.x + ((p4.x-p1.x)/2), p1.y + ((p4.y-p1.y)/2));
 	double m1 = (p2.y-y1)/dx1;
 	double m2 = (p3.y-y4)/dx2;
 	
@@ -101,10 +108,18 @@ Point intersectLines( Point p1, Point p2, Point p3, Point p4 ) {
 		return Point( x1, (m2*(x1-x4))+y4 );
 	} else if( !dx2 ) {
 		return Point( x4, (m1*(x4-x1))+y1 );
+	} else if( fabs( m1-m2 ) < .001 ) {
+		return Point( x4, (m1*(x4-x1))+y1 );
 	}
 	double x = ((-m2 * x4) + y4 + (m1 * x1) - y1) / (m1-m2);
 	Point p( x, (m1 * (x-x1)) + y1 );
-	//fprintf(stderr,"S: %f/%f  m1/2: %f/%f\n", p.x, p.y, m1, m2 );
+	
+/*	
+	if( fabs(p.y) > 100 ) {
+		fprintf(stderr,"p1/2: %f/%f %f/%f %f/%f %f/%f\n", p1.x, p1.y, p2.x, p2.y, p3.x, p3.y, p4.x, p4.y );
+		fprintf(stderr,"S: %f/%f  m1/2: %f/%f\n", p.x, p.y, m1, m2 );
+	}
+*/
 	return p;
 }
 
@@ -131,8 +146,8 @@ void ShapeMaker::cubicToRec( const Point& a, const Point& b, const Point& c, con
 	double dy = (a.y+d.y+s.y*4-(b.y+c.y)*3)*.125;
 	Bezier bz( a, b, c, d );
 	Bezier b0, b1;
-	if( dx*dx + dy*dy > k && iteration<100 ) {
-		//fprintf(stderr,"split: %f\n",dx*dx + dy*dy);
+	if( dx*dx + dy*dy > k && iteration<10 ) {
+//		fprintf(stderr,"[%03i] split: %f\n", iteration, dx*dx + dy*dy);
 		bezierSplit( bz, &b0, &b1 );
 		// recurse
 		iteration++;
@@ -144,7 +159,7 @@ void ShapeMaker::cubicToRec( const Point& a, const Point& b, const Point& c, con
 		//lineTo( b1.p2.x, b1.p2.y );
 		//lineTo( d.x, d.y );
 	} else {
-	//	fprintf(stderr,"#### %i %i %i %i\n", (int)s.x, (int)s.y, (int)d.x, (int)d.y );
+//		fprintf(stderr,"#### %i %i %i %i\n", (int)s.x, (int)s.y, (int)d.x, (int)d.y );
 		//lineTo( (int)s.x, (int)s.y );
 		//lineTo( (int)d.x, (int)d.y );
 		curveTo( s.x, s.y, d.x, d.y );
@@ -157,7 +172,7 @@ void ShapeMaker::cubicTo( double x1, double y1, double x2, double y2, double ax,
 	Point c(x2,y2);
 	Point d(ax,ay);
 
-	cubicToRec( a, b, c, d, .1 );
+	cubicToRec( a, b, c, d, .01 );
 	//lastx = ax; lasty = ay;
 }
 
@@ -165,14 +180,14 @@ void ShapeMaker::close() {
 	// diffx/diffy captures rounding errors. they can accumulate a bit! FIXME
 	
 	if( diffx || diffy ) {
-		fprintf(stderr,"WARNING: shape not closed; closing (%i/%i).\n", diffx, diffy);
+		fprintf(stderr,"WARNING: shape not closed; closing (%f/%f).\n", diffx, diffy);
 		fprintf(stderr,"DEBUG: accumulated rounding error (%f/%f).\n", roundx, roundy);
 		// closing line
 		LineTo *segment = new LineTo;
 		segment->setType(1);
 		//segment->setbits( maxBitsNeeded( true, 2, x, y ) );
-		segment->setx( -diffx );
-		segment->sety( -diffy );
+		segment->setx( (int)-diffx );
+		segment->sety( (int)-diffy );
 		edges->append( segment );
 	}
 
@@ -185,9 +200,9 @@ void ShapeMaker::finish() {
 	edges->append( setup );
 }
 
-void ShapeMaker::setup( double x, double y, int fillStyle0, int fillStyle1, int lineStyle ) {
+void ShapeMaker::setup( double x, double y ) {
 	x+=offsetx; y+=offsety;
-	setupR( x-lastx, y-lasty, fillStyle0, fillStyle1, lineStyle );
+	setupR( x-lastx, y-lasty );
 	lastx = x;
 	lasty = y;
 }
