@@ -828,9 +828,29 @@ size_t DefineShape4::calcSize( Context *ctx, int start_at ) {
 size_t DefineShape5::calcSize( Context *ctx, int start_at ) {
 	size_t r = start_at;
 	
+	ctx->alpha = 1;
+
+	ctx->many_shapes = 1;
+
+	ctx->tagVersion = 5;
+
 	r += 16;
 
-	r += data.getSize(ctx,r);
+	r += bounds.getSize(ctx,r);
+
+	r += strokeBounds.getSize(ctx,r);
+
+	r += 6;
+
+	r++;
+
+	r++;
+
+	r += styles.getSize(ctx,r);
+
+	r += shapes.getSize(ctx,r);
+
+	if( r%8 != 0 ) r += 8-(r%8);
 
 
 	r += Tag::getHeaderSize( r-start_at );
@@ -3407,8 +3427,63 @@ size_t LineStyle::calcSize( Context *ctx, int start_at ) {
 	
 	r += 16;
 
+	if( ctx->tagVersion < 4 ) {
+		
 	r += color.getSize(ctx,r);
 
+	}
+
+	if( ctx->tagVersion > 3 ) {
+		
+	r += 2;
+
+	r += 2;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r++;
+
+	r += 5;
+
+	r++;
+
+	r += 2;
+
+	if( jointStyle==2 ) {
+		
+	r += 16;
+
+	}
+
+	if( hasFill ) {
+		
+	{
+		Style* item;
+		ListItem<Style>* i;
+		i = fillStyles.first();
+		while( i ) {
+			item = i->data();
+			if( item ) {
+				r += item->getSize(ctx,r);
+			}
+			i = i->next();
+		}
+	}
+
+	}
+
+	if( !hasFill ) {
+		
+	r += fillColor.getSize(ctx,r);
+
+	}
+
+	}
+
 
 //	printf("LineStyle sz %i bits (%.2f bytes, start %i)\n", r-start_at, ((float)r-start_at)/8, start_at );
 
