@@ -4,15 +4,19 @@
 #include "xslt.h"
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
+#include <dirent.h>
 
 using namespace SWF;
 
 bool quiet = false;
 bool verbose = false;
 bool dump = false;
-bool simple = false;
+const char *internal_stylesheet = NULL;
 
 void usage() {
 	fprintf( stderr,
@@ -52,8 +56,8 @@ void usage() {
 		"\n"
 		"<option>s are:\n"
 		"    -h print this help and quit\n"
-		"    -q be quiet, only print errors and warnings\n"
-		"    -v verbose output (for debugging)\n"
+		"    -v verbose output\n"
+		"    -V extra-verbose debugging output\n"
 		"    -d dump SWF data when loaded (for debugging)\n"
 		"\n"
 		"E-mail bug reports to "PACKAGE_BUGREPORT"\n\n"
@@ -76,7 +80,8 @@ int swfmill_swf2xml( int argc, char *argv[] ) {
 	bool std_in, std_out;
 
 	File input;
-	int size, xmlsize;
+	unsigned int filesize, size, xmlsize;
+    struct stat filestat;
 	char sig;
 	Context ctx;
 
@@ -99,12 +104,21 @@ int swfmill_swf2xml( int argc, char *argv[] ) {
 	
 	if( !quiet ) fprintf(stderr,"Reading from %s\n", infile );
 	
+// stat filesize
+    filesize = (unsigned int)-1;
+    
+    if( !std_in ) {
+        stat( infile, &filestat );
+        filesize = filestat.st_size;
+//        fprintf(stderr,"Filesize: %u\n",filesize);
+    }
+    
 // setup context
 	ctx.debugTrace = verbose;
 	ctx.quiet = quiet;
 
 		// treat input as SWF, produce XML
-		if( (size = input.load( in_fp, &ctx )) != 0 ) {
+		if( (size = input.load( in_fp, &ctx, filesize )) != 0 ) {
 			if( dump ) input.dump();
 			out_fp = std_out ? stdout : fopen( outfile, "wb" );
 			if( !out_fp ) {
@@ -169,16 +183,23 @@ int swfmill_xml2swf( int argc, char *argv[] ) {
 			goto fail;
 		}
 
-		// treat input as XML, produce SWF
-		if( simple ) {
-			transform = xsltParseStylesheetMemory( xslt_library, strlen(xslt_library) );
+		// see if one of the internal stylesheets should be used
+		if( internal_stylesheet ) {
+			transform = xsltParseStylesheetMemory( internal_stylesheet, strlen(internal_stylesheet) );
 			if( !transform ) {
-				fprintf( stderr, "ERROR: internal library stylesheet could not be read.\n" );
+				fprintf( stderr, "ERROR: internal stylesheet could not be read.\n" );
 				goto fail;
 			}
-			
-			doc2 = xsltApplyStylesheet( transform, doc, NULL );
-			
+
+			const char *params[3];
+			params[0] = "quiet";
+			params[1] = "\"false\"";
+			params[2] = NULL;
+			if( quiet ) {
+				params[1] = "\"true\"";
+			}
+			doc2 = xsltApplyStylesheet( transform, doc, (const char **)&params );
+
 			if( !doc2 ) {
 				fprintf( stderr, "ERROR: transformation failed.\n" );
 				goto fail;
@@ -188,6 +209,7 @@ int swfmill_xml2swf( int argc, char *argv[] ) {
 			doc = doc2;
 		}
 		
+		// treat input as XML, produce SWF
 		input.setXML( doc->xmlRootNode, NULL );
 		if( dump ) input.dump();
 		out_fp = std_out ? stdout : fopen( outfile, "wb" );
@@ -211,18 +233,12 @@ fail:
 }
 
 
+int swfmill_do_xslt( xmlDocPtr doc, xsltStylesheetPtr transform, const char *outfile );
+
 int swfmill_xslt( int argc, char *argv[] ) {
 	const char *xslfile, *infile, *outfile = "stdout";
-	xsltStylesheetPtr transform = NULL;
-	xmlDocPtr doc = NULL, doc2 = NULL;
-	FILE *out_fp;
-	const char *ext;
-	Context ctx;
-	int size;
-
-// setup context
-	ctx.debugTrace = verbose;
-	ctx.quiet = quiet;
+	xmlDocPtr doc = NULL;
+	xsltStylesheetPtr transform;
 	
 	// parse filenames
 	if( argc < 2 || argc > 3 ) {
@@ -245,8 +261,34 @@ int swfmill_xslt( int argc, char *argv[] ) {
 		goto fail;
 	}
 	
-	if( !quiet ) fprintf( stderr, "Applying XSLT %s to %s...\n", xslfile, infile );
-	doc2 = xsltApplyStylesheet( transform, doc, NULL );
+	return swfmill_do_xslt( doc, transform, outfile );
+	
+	fail:
+		return -1;
+}
+
+int swfmill_do_xslt( xmlDocPtr doc, xsltStylesheetPtr transform, const char *outfile ) {
+	xmlDocPtr doc2 = NULL;
+	FILE *out_fp;
+	const char *ext;
+	Context ctx;
+	int size;
+
+	const char *params[3];
+	params[0] = "quiet";
+	params[1] = "\"FALSE\"";
+	params[2] = NULL;
+	if( quiet ) {
+		params[1] = "\"FALSE\"";
+	}
+	
+	// setup context
+	ctx.debugTrace = verbose;
+	ctx.quiet = quiet;
+
+	
+	if( !quiet ) fprintf( stderr, "Applying XSLT...\n" );
+	doc2 = xsltApplyStylesheet( transform, doc, params );
 	
 	if( !doc2 ) {
 		fprintf( stderr, "ERROR: transformation failed.\n" );
@@ -286,12 +328,87 @@ fail:
 }
 
 
+void swfmill_create_library( xmlNodePtr lib, const char *filename );
+
+void swfmill_create_library_dir( xmlNodePtr lib, const char *dir ) {
+	char tmp[256];
+	
+	struct dirent *e;
+	DIR *d = opendir( dir );
+	if( d == NULL ) return;
+		
+	while( true ) {
+		e = readdir(d);
+		if( e==NULL ) break;
+		if( e->d_name[0] == '.' ) continue; // no hidden files
+		
+		snprintf( tmp, 1023, "%s/%s", dir, e->d_name );
+		swfmill_create_library( lib, tmp );
+	}
+}
+
+void swfmill_create_library( xmlNodePtr lib, const char *filename ) {
+	struct stat s;
+	if( stat(filename,&s) ) return;
+
+/*
+	int i=strlen(filename)-1;
+	while( i>0 && filename[i]!='.' ) i--;
+	const char *ext = &filename[i];
+*/	
+	if( S_ISDIR(s.st_mode) ) {
+		swfmill_create_library_dir( lib, filename );
+	} else {
+//		if( !strcmp( ext, ".jpg" ) || !strcmp( ext, ".jpeg" ) ) {
+		
+		xmlNodePtr node = xmlNewChild( lib, NULL, (const xmlChar*)"clip", NULL );
+		xmlSetProp( node, (const xmlChar *)"id", (const xmlChar *)filename );
+		xmlSetProp( node, (const xmlChar *)"import", (const xmlChar *)filename );
+	}
+	
+//	fprintf(stderr, "clip %s: %s (%s)\n", filename, S_ISDIR(s.st_mode)?"dir":"file", ext );
+	
+}
+
+int swfmill_library( int argc, char *argv[] ) {
+	if( argc < 2 ) {
+		fprintf( stderr, "library creation needs at least two arguments\n\tswfmill library <input file(s)/dir(s)> <output>.swf\n" );
+		return -1;
+	}
+	const char *outfile = argv[argc-1];
+	argc--;
+		
+	internal_stylesheet = xslt_simple;
+	
+	xmlDocPtr doc = xmlNewDoc((const xmlChar*)"1.0");
+	doc->children = xmlNewDocNode( doc, NULL, (const xmlChar*)"movie", NULL );
+	
+	xmlNodePtr lib = xmlNewChild( doc->children, NULL, (const xmlChar *)"library", NULL );
+	
+	for( int i=0; i<argc; i++ ) {
+		swfmill_create_library( lib, argv[i] );
+	}
+	
+	xmlNodePtr node = xmlNewChild( lib, NULL, (const xmlChar *)"frame", NULL );
+//	xmlSetProp( node, (const xmlChar*)"id", (const xmlChar *)"foo");
+	
+	xsltStylesheetPtr transform = xsltParseStylesheetMemory( internal_stylesheet, strlen(internal_stylesheet) );
+	if( !transform ) {
+		fprintf( stderr, "ERROR: internal stylesheet could not be read.\n" );
+		return -1;
+	}
+	
+	swfmill_do_xslt( doc, transform, outfile );
+}
+
 int main( int argc, char *argv[] ) {
 	char *command = NULL;
 	
 	swft_register();
 	exsltRegisterAll();
 
+	quiet = true;
+	
 // parse args
 	int i=1;
 	for( ; i<argc && command==NULL; i++ ) {
@@ -303,6 +420,9 @@ int main( int argc, char *argv[] ) {
 						quiet = true;
 						break;
 					case 'v':
+						quiet = false;
+						break;
+					case 'V':
 						verbose = true;
 						break;
 					case 'd':
@@ -338,8 +458,10 @@ int main( int argc, char *argv[] ) {
 	} else if( !strcmp( command, "xslt" ) ) {
 		return swfmill_xslt( argc-i, &argv[i] );
 	} else if( !strcmp( command, "simple" ) ) {
-		simple = true;
+		internal_stylesheet = xslt_simple;
 		return swfmill_xml2swf( argc-i, &argv[i] );
+	} else if( !strcmp( command, "library" ) ) {
+		return swfmill_library( argc-i, &argv[i] );
 	} else {
 		fprintf(stderr,"ERROR: unknown command %s\n", command );
 		usage();
