@@ -1076,20 +1076,16 @@ const char *xslt_simple =
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"@objectID|@fontRef|@sprite\" mode=\"idmap\">\n"
 "	<xsl:attribute name=\"{name()}\"><xsl:value-of select=\"swft:map-id(.)\"/></xsl:attribute>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"@*|text()\" mode=\"idmap\" priority=\"-1\">\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"text()\" mode=\"idmap\" priority=\"-1\">\n"
 "	<xsl:copy select=\".\"/>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"DefineShape|DefineShape2|DefineShape3\" mode=\"idmap\">\n"
-"	<xsl:copy select=\".\">\n"
-"		<xsl:apply-templates select=\"@*|text()\" mode=\"idmap\"/>\n"
-"        <xsl:for-each select=\"*\">\n"
-"            <xsl:copy-of select=\".\"/>\n"
-"        </xsl:for-each>\n"
-"	</xsl:copy>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"@*\" mode=\"idmap\" priority=\"-1\">\n"
+"	<xsl:copy select=\".\"/>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"*\" mode=\"idmap\" priority=\"-1\">\n"
 "	<xsl:copy select=\".\">\n"
-"		<xsl:apply-templates select=\"*|@*|text()\" mode=\"idmap\"/>\n"
+"		<xsl:apply-templates select=\"@*\" mode=\"idmap\"/>\n"
+"		<xsl:apply-templates mode=\"idmap\"/>\n"
 "	</xsl:copy>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"SetBackgroundColor\" mode=\"sprite-global\"/>\n"
